
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MeshMTCSingleStudyGLM.m
% Example script showing how to run statistics with the new "mesh" object
%
% Created by Rainer Goebel, May 2013, HB June 2013, April, June 2021
% Works with BrainVoyager 22
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Start BrainVoyager
success = 1;
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
% Load anatomical file (*.vmr)
[FileName, PathName] = uigetfile('*.vmr', 'Please select the anatomical file (*.vmr)');
docVMR = bv.OpenDocument(fullfile(PathName, FileName));
if (~isinterface(docVMR)), disp('Could not open VMR.'); success = 0; end;
% Load surface file (*.srf)
[FileName, PathName] = uigetfile('*.srf', 'Please select the mesh (*.srf)');
srfname = [PathName FileName];
ok = docVMR.LoadMesh(srfname);
if (~isinterface(docVMR)), ok = 0;
else meshSRF = docVMR.CurrentMesh;
    if (~isinterface(meshSRF)), ok = 0; end;
end;
% Link mesh time course (*.mtc)
if (ok)
    [FileName, PathName] = uigetfile('*.mtc', 'Please select the mesh (*.mtc)');
    ok = meshSRF.LinkMTC(fullfile(PathName, FileName)); %if(!ok) return;
end;
% Load single subject design matrix (*.sdm)
if (ok)
    meshSRF.ClearDesignMatrix();
    [FileName, PathName] = uigetfile('*.sdm', 'Please select the design matrix (*.sdm)');
    sdmname = fullfile(PathName, FileName);
    [pathstrSDM, nameSDM, extSDM] = fileparts(sdmname);
    ok = meshSRF.LoadSingleStudyGLMDesignMatrix(sdmname); %if(!ok) return;
end;
% Run the single subject GLM
if (ok)
    meshSRF.CorrectForSerialCorrelations = 2; % 1 -> AR(1), 2 -> AR(2)
    meshSRF.ComputeSingleStudyGLM();
    meshSRF.ShowGLM();
    meshSRF.SaveGLM(fullfile(pathstrSDM, [nameSDM '_MeshGLM_FROMSCRIPT.glm']));
end;
% docVMR.Close();
% ok = meshSRF.LinkStimulationProtocolToMTC(ObjectsRawDataPath + 'CG_OBJECTS_FROMSCRIPT.prt');
