%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% bvprotocol_to_bvdesignmatrix.m
%
% Script to create a design matrix from a stimulation protocol in Matlab
% Usage: load script in Matlab, click 'Run'. File dialogs will appear to
% ask for the VMR, VTC and stimulation protocol. The single-subject design
% matrix (*.sdm) and GLM will be automatically saved to disk in the
% directory of the VTC file.
%
% Data: Getting Started Guide 4. Works with BrainVoyager 22
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
bv.PrintToLog('Create design matrix in Matlab...');
[vmrName, vmrDir] = uigetfile('*.vmr','Please select the VMR file...');
vmrfilename = fullfile(vmrDir, vmrName);
vmr = bv.OpenDocument(vmrfilename);
bv.ResizeWindow(600,400);
[vtcName, vtcDir] = uigetfile('*.vtc','Please select the VTC file...');
vtcfilename = fullfile(vtcDir, vtcName);
bv.PrintToLog(['Link vtc file: ' vtcfilename]);
vmr.LinkVTC(vtcfilename);
[prtName, prtDir] = uigetfile('*.prt','Please select the protocol file...');
prtname = fullfile(prtDir, prtName);
vmr.LinkStimulationProtocol(prtname);
bv.PrintToLog(['Link stimulation protocol: ' prtname]);

vmr.ClearDesignMatrix();
vmr.AddPredictor('Faces_LVF');
vmr.SetPredictorValuesFromCondition('Faces_LVF', 'Faces_LVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Faces_LVF');
vmr.AddPredictor('Houses_RVF');
vmr.SetPredictorValuesFromCondition('Houses_RVF', 'Houses_RVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Houses_RVF');
vmr.AddPredictor('Faces_CVF');
vmr.SetPredictorValuesFromCondition('Faces_CVF', 'Faces_CVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Faces_CVF');
vmr.AddPredictor('Houses_LVF');
vmr.SetPredictorValuesFromCondition('Houses_LVF', 'Houses_LVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Houses_LVF');
vmr.AddPredictor('Faces_RVF');
vmr.SetPredictorValuesFromCondition('Faces_RVF', 'Faces_RVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Faces_RVF');
vmr.AddPredictor('Houses_CVF');
vmr.SetPredictorValuesFromCondition('Houses_CVF', 'Houses_CVF', 1.0);
vmr.ApplyHemodynamicResponseFunctionToPredictor('Houses_CVF');
vmr.SaveSingleStudyGLMDesignMatrix(fullfile(vtcDir, 'FacesHousesDesignMatrix.sdm'));
bv.PrintToLog(['Saved design matrix: ' fullfile(vtcDir, 'FacesHousesDesignMatrix.sdm')]);
% vmr.FirstConfoundPredictorOfSDM
% run the GLM
vmr.SDMContainsConstantPredictor = 0;
vmr.CorrectForSerialCorrelations = 2; % If set to 1, AR(1) is used, if set to 2, AR(2) is used.
vmr.ComputeSingleStudyGLM;
vmr.ShowGLM;
vmr.SaveGLM(fullfile(vtcDir, 'FacesHouses_VTC.glm'));
bv.PrintToLog(['Saved GLM: ' fullfile(vtcDir, 'FacesHouses_VTC.glm')]);

