
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% coregister_fmr_vmr_create_vtc.m
% Interactive script: given an anatomical file (*.vmr) and functional file (*.fmr), 
% create a normalised file (*.vtc) using image registration
% Created with BrainVoyager 22
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
[FileName,PathName] = uigetfile('*.vmr', 'Please select the VMR file ');
vmr = bv.OpenDocument([PathName FileName]);
[FileName,PathName] = uigetfile('*.fmr', 'Please select the FMR file ');
fmrname = fullfile(PathName, FileName);
useAmr = 1;
success = vmr.CoregisterFMRToVMR(fmrname,useAmr);
%% discover the IA and FA names (should be in FMR directory)
iaTrfSelection = [PathName '*_IA.trf'];
iaTrfFiles = dir(iaTrfSelection);
faTrfSelection = [PathName '*_FA.trf'];
faTrfFiles = dir(faTrfSelection);
[pathstr,name,ext] = fileparts(fmrname); 
vtcname = fullfile(pathstr, [name '.vtc']);
%% create VTC in native space
resolution = 3;
interpolation = 1; % trilinear
bbithresh = 100;
datatype = 2; % float 32
success = vmr.CreateVTCInVMRSpace(fmrname, fullfile(pathstr, iaTrfFiles(1).name), fullfile(pathstr, faTrfFiles(1).name),...
vtcname, datatype, resolution, interpolation, bbithresh);
if (success), bv.PrintToLog(['Created VTC file: ' vtcname]); end

