%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create_cgobjects_protocol.m; script to create stimulation protocol in
% Matlab
% Works with BrainVoyager 22.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
bv.ShowLogTab;
bv.PrintToLog('Creating a BrainVoyager stimulation protocol from Matlab...');
[FileName,PathName] = uigetfile('*.vmr', 'Please select the anatomical file ');
doc = bv.OpenDocument([PathName FileName]);
[FileName,PathName] = uigetfile('*.vtc', 'Please select the functional file ');
doc.LinkVTC(fullfile(PathName, FileName));
doc.ClearStimulationProtocol();
doc.StimulationProtocolExperimentName = 'Faces Houses in LVF, CVF, RVF';
doc.StimulationProtocolResolution = 1;
doc.AddCondition('Faces_LVF');
doc.AddCondition('Houses_RVF');
doc.AddCondition('Faces_CVF');
doc.AddCondition('Houses_LVF');
doc.AddCondition('Faces_RVF');
doc.AddCondition('Houses_CVF');
doc.AddInterval('Faces_LVF', 4, 11);
doc.AddInterval('Houses_RVF', 20, 27);
doc.AddInterval('Faces_CVF', 36, 43);
doc.AddInterval('Houses_LVF', 52, 59);
doc.AddInterval('Faces_RVF', 68, 75);
doc.AddInterval('Houses_CVF', 84, 91);
doc.AddInterval('Faces_LVF', 100, 107);
doc.AddInterval('Houses_RVF', 116, 123);
doc.AddInterval('Faces_CVF', 132, 139);
doc.AddInterval('Houses_LVF', 148, 155);
doc.AddInterval('Faces_RVF', 164, 171);
doc.AddInterval('Houses_CVF', 180, 187);
doc.AddInterval('Faces_LVF', 196, 203);
doc.AddInterval('Houses_RVF', 212, 219);
doc.AddInterval('Faces_CVF', 228, 235);
doc.AddInterval('Houses_LVF', 244, 251);
doc.AddInterval('Faces_RVF', 260, 267);
doc.AddInterval('Houses_CVF', 276, 283);
doc.SetConditionColor('Faces_LVF', 200, 43, 43);
doc.SetConditionColor('Houses_RVF', 200, 200, 43);
doc.SetConditionColor('Faces_CVF', 43, 200, 43);
doc.SetConditionColor('Houses_LVF', 43, 200, 200);
doc.SetConditionColor('Faces_RVF', 43, 43, 200);
doc.SetConditionColor('Houses_CVF', 200, 43, 200);
doc.StimulationProtocolBackgroundColorR = 0;
doc.StimulationProtocolBackgroundColorG = 0;
doc.StimulationProtocolBackgroundColorB = 0;
doc.StimulationProtocolTimeCourseColorR = 255;
doc.StimulationProtocolTimeCourseColorG = 255;
doc.StimulationProtocolTimeCourseColorB = 255;
doc.StimulationProtocolTimeCourseThickness = 2;
prtname = fullfile(PathName, 's01_sess4_blocked_vol_script.prt');
doc.SaveStimulationProtocol(prtname);
bv.PrintToLog(['Created protocol: ' prtname]);
doc.Save(); % to save link to protocol permanently
