%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create_multiple_vtcs.m
% Script to create volume time course files (*.vtc)
% For use: load in Matlab and press 'run'.
%
% Works with BrainVoyager 22
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h = msgbox(['Via this script will be multiple VTCs created. Please first define all parameters...'])
uiwait(h);
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1');
bv.ShowLogTab;
bv.PrintToLog('Creating VTC files from Matlab...');
loadparams = questdlg('Would you like to load VTC parameters (from earlier use of this script)?',...
    'Create multiple VTCs');
if strcmp(loadparams, 'Yes') == 1
    [FileName,PathName] = uigetfile('*.mat', 'Please select the VTC parameters file ');
    load([PathName FileName]);
else
    answer = inputdlg('Please enter the number of projects...','Create multiple VTCs',1);
    if isnumeric(str2num(answer{1})) && str2num(answer{1}) > 0
        nrofprojects = str2num(answer{1});
    end
    % create cell arrays to store the vtc parameters
    fmr_names = cell(nrofprojects, 1);
    ia_names = cell(nrofprojects, 1);
    fa_names = cell(nrofprojects, 1);
    acpc_names = cell(nrofprojects, 1);
    tal_names = cell(nrofprojects, 1);
    mni_names = cell(nrofprojects, 1);
    vtc_names = cell(nrofprojects, 1);
    vtcspaces = {'native', 'acpc', 'talairach', 'mni'};
    [space,v] = listdlg('PromptString','select the target space:',...
        'SelectionMode','single',...
        'Name', 'Create multiple VTCs',...
        'ListSize', [200 160],...
        'ListString', vtcspaces)
    for i=1:nrofprojects
        [FileName,PathName] = uigetfile('*.fmr', ...
            ['Please select FMR file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
        fmr_names{i,1} = strcat(PathName, FileName);
        [FileName,PathName] = uigetfile('*_IA.trf', ...
            ['Please select initial alignment file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
        ia_names{i,1} = strcat(PathName, FileName);
        [FileName,PathName] = uigetfile('*_FA.trf', ...
            ['Please select fine alignment file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
        fa_names{i,1} = strcat(PathName, FileName);
        if ((space == 2) || (space == 3)) 
            [FileName,PathName] = uigetfile('*_ACPC.trf', ...
                ['Please select AC-PC alignment file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
            acpc_names{i,1} = strcat(PathName, FileName);
            if (space == 3)
                [FileName,PathName] = uigetfile('*.tal', ...
                    ['Please select Talairach landmarks file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
                tal_names{i,1} = strcat(PathName, FileName);
            end
        elseif (space == 4)
                [FileName,PathName] = uigetfile('*_a12.trf', ...
                    ['Please select MNI transformation file ' num2str(i) ' of ' num2str(nrofprojects) '...']);
                mni_names{i,1} = strcat(PathName, FileName);
        end
        
        [pathstr,name,ext] = fileparts(fmr_names{i,1});
        vtc_names{i,1} = fullfile(pathstr, [name '_' vtcspaces{space} '.vtc']);
    end
    resolution = 3;
    answer = inputdlg('Please enter the voxel resolution...','Create multiple VTCs',1,{num2str(resolution)});
    if isnumeric(str2num(answer{1})) && str2num(answer{1}) > 0
        resolution = str2num(answer{1});
    end
    interpolation = 1; % trilinear
    bbithresh = 100;
    cerebellum = 0;
    if space < 3
        answer = inputdlg('Please enter an intensity threshold...','Create multiple VTCs',1,{num2str(bbithresh)});
        if isnumeric(str2num(answer{1})) && str2num(answer{1}) > 0
            bbithreshold = str2num(answer{1});
        end
    else
        button = questdlg('Would you like an extended Talairach space (incl. cerebellum)?','Create multiple VTCs');
        if strcmp(button, 'Yes') == 1, cerebellum = 1; end
    end
    button = questdlg('Would you like high-precision data (float format)?','float or integer format');
    if strcmp(button, 'Yes') == 1
        datatype = 2; % float 32
    else
        datatype = 1; % integer 16-bit
    end
    [FileName,PathName] = uigetfile('*.vmr','Please select the anatomical data file...');
    vmrfilename = [PathName FileName];
end
vmr = bv.OpenDocument(vmrfilename);
vmr.ExtendedTALSpaceForVTCCreation = cerebellum;
for i=1:nrofprojects
    if space == 1
        success = vmr.CreateVTCInVMRSpace(fmr_names{i,1}, ia_names{i,1}, fa_names{i,1},...
            vtc_names{i,1}, datatype, resolution, interpolation, bbithresh);
    elseif space == 2
        success = vmr.CreateVTCInACPCSpace(fmr_names{i,1}, ia_names{i,1}, fa_names{i,1},...
            acpc_names{i,1}, vtc_names{i,1}, datatype, ...
            resolution, interpolation, bbithresh);
    elseif space == 3
        success = vmr.CreateVTCInTALSpace(fmr_names{i,1}, ia_names{i,1}, fa_names{i,1},...
            acpc_names{i,1}, tal_names{i,1}, vtc_names{i,1}, datatype, ...
            resolution, interpolation, bbithresh);
    elseif space == 4
        success = vmr.CreateVTCInMNISpace(fmr_names{i,1}, ia_names{i,1}, fa_names{i,1},...
            mni_names{i,1}, vtc_names{i,1}, datatype, ...
            resolution, interpolation, bbithresh);
    else
        disp('An error occurred. Our apologies');
    end
    if (success == 1)
        bv.PrintToLog(['Created ' vtc_names{i,1}]);
    else
        disp(['An error occurred while creating the VTC file' vtc_names{i,1}]);
    end
end
button = questdlg('Would you like to save the VTC parameters (for later use of this script)?','Create multiple VTCs');
if strcmp(button, 'Yes') == 1
    vtcparamsfilename = fullfile(pathstr, 'vtcparams.mat')
    save(vtcparamsfilename); % save workspace variables to a file
end