%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% create_multistudy_designmatrix.m; script to create BrainVoyager multi-study design matrix
% and compute GLM in Matlab.
% Script assumes that functional data (*.vtc) are in same folder as
% single-subject design matrix files (*.sdm) and automatically pairs the
% runs with the design matrix files based on the names (*run1*, *run2*).  
% Works with BrainVoyager 22
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% create COM server, ask for the anatomy (*.vmr) and single-subject design matrix (*.sdm) files
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
[FileName PathName] = uigetfile('*.vmr')
doc = bv.OpenDocument([PathName FileName]);
doc.ClearMultiStudyGLMDefinition;
[FileName PathName] = uigetfile('*.sdm', 'Select the design matrix file for run 1')
sdm1 = fullfile(PathName, FileName);
[FileName PathName] = uigetfile('*.sdm', 'Select the design matrix file for run 2')
sdm2 = fullfile(PathName, FileName);
% create the multi-study design matrix
vtcstruct = dir([PathName '*.vtc']) % assumes all files are in same folder
subjset = size(vtcstruct)
for i = 1:subjset(1)
    isrun1 = strfind(vtcstruct(i).name, 'run1')
    if ~isempty(isrun1)
        doc.AddStudyAndDesignMatrix(vtcstruct(i).name, sdm1);
    else
        doc.AddStudyAndDesignMatrix(vtcstruct(i).name, sdm2);
    end
end
doc.SaveMultiStudyGLMDefinitionFile(fullfile(PathName, 'MultiStudy_fromBVMatlabScript.mdm'))
doc.LoadMultiStudyGLMDefinitionFile(fullfile(PathName, 'MultiStudy_fromBVMatlabScript.mdm'))
doc.ComputeMultiStudyGLM
