
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% diffusion_weighted_data.m
% Assumes: a) all data are in same folder b) for VDW creation: data are 
% aligned and anatomical volume is transformed to all spaces (please 
% comment lines out if not the case)
% 
% Usage: load in BrainVoyager, click 'Run'. Pop-up boxes will appear to ask
% whether to create a diffusion weighted document, and to create VDW files.
%
% Works with BrainVoyager 22
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
bv.PrintToLog('Start processing diffusion weighted data...');
%  this part will require modifications, if used for own purposes 
dmrname = 'D:/BVData/diffusion/human31dir_from_script.dmr'; % this variable is also used in 2nd part
answer = questdlg('Create diffusion weighted document?', 'Create DMR');
if strcmp(answer,'Yes')
    dmr = bv.CreateDocumentDMR( 'DICOM', ...
        'D:/BVData/diffusion/pimpul_070907_dti -0007-0001-00001.dcm', ...
        31, 0, true, 75, 'human31dir', false, 128, 128, 2, 'D:/BVData/diffusion');
    dmr.TR = 8900;
    dmr.InterSliceTime = 118;
    dmr.TimeResolutionVerified = 1;
    dmr.SaveAs(dmrname);
end
%  this part does not require modifications, is all user-interface based 
% if alignment files happen to be available, one could as well create
% normalized diffusion weighted data files:
answer = questdlg('Create normalized diffusion weighted data? (requires *.trf files)', 'Create VDW');
if strcmp(answer, 'Yes')
    [pathstr, name, ext] = fileparts(dmrname)
    [FileName, PathName] = uigetfile('*.vmr','Please select the anatomical file...');
    vmr = bv.OpenDocument([PathName FileName]);
    % assumes a single initial alignment file in the directory of the VMR
    iafilename = dir([PathName '*_IA.trf'])
    % assumes a single fine alignment file in the directory of the VMR
    fafilename = dir([PathName '*_FA.trf'])
    % assumes a single AC-PC transformation file in the directory of the VMR
    acpcfilename = dir([PathName '*ACPC.trf'])
    % assumes a single Talairach landmark file in the directory of the VMR
    talfilename = dir([PathName '*.tal'])
    answer = questdlg('Would you like 32-bit float datatype? (Otherwise 16-bit integer)', 'Datatype');
    if strcmp(answer, 'Yes')
        datatype = 2;
    else
        datatype = 1;
    end
    resolutionlist = {'1mm3', '2mm3', '3mm3'};
    [resolution, ok] = listdlg('PromptString','Select the target VTC resolution:',...
        'SelectionMode','single',...
        'Name', 'VDW resolution',...
        'ListString', resolutionlist);
    interpolationlist = {'nearest neighbor', 'trilinear', 'sinc'};
    [interpolation, ok] = listdlg('PromptString','Select the interpolation type:',...
        'SelectionMode','single',...
        'Name', 'Interpolation',...
        'ListString', interpolationlist)
    interpolation = interpolation - 1; % 0: nearest neighbour, 1: trilinear interpolation, 2: interpolation.
    prompt = {'Enter intensity threshold:'};%,'Enter colormap name:'};
    dlg_title = 'Intensity threshold';
    num_lines = 1;
    def = {'100'};%,'hsv'};
    threshold = inputdlg(prompt,dlg_title,num_lines,def);
    ia = fullfile(PathName, iafilename(1).name) % takes first initial alignment file it finds in folder
    fa = fullfile(PathName, fafilename(1).name) % takes first fine alignment file it finds in folder
    acpc = fullfile(PathName, acpcfilename(1).name) % takes first AC-PC alignment file it finds in folder
    tal = fullfile(PathName, talfilename(1).name) % takes first Talairach landmarks file it finds in folder
    thresh = str2num(threshold{1});
    vmr.ExtendedTALSpaceForVTCCreation = 0; % no extended bounding box for cerebellum
    vdw = fullfile(pathstr, [name '_native.vdw'])
    success = vmr.CreateVDWInVMRSpace(dmrname,ia,fa,vdw,datatype,resolution, interpolation, thresh);
    vdw = fullfile(pathstr, [name '_acpc.vdw'])
    success = vmr.CreateVDWInACPCSpace(dmrname,ia,fa,acpc,vdw,datatype,resolution, interpolation, thresh);
    vdw = fullfile(pathstr, [name '_tal.vdw'])
    success = vmr.CreateVDWInTALSpace(dmrname,ia,fa,acpc,tal,vdw,datatype,resolution, interpolation, thresh);
    end
bv.PrintToLog('Finished processing diffusion weighted data.');