%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script to preprocess a VTC file in Matlab
% preprocess_vtc.m
% Works in BrainVoyager 22.2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
bv.ShowLogTab;
bv.PrintToLog('Preprocessing VTC files from Matlab...');
doc = bv.ActiveDocument;
if (isempty(doc))
[FileName,PathName] = uigetfile('*.vmr', 'Please select the VMR file ');
vmr = bv.OpenDocument([PathName FileName]);
end
vtc = vmr.FileNameOfCurrentVTC;
if (isempty(vtc))
[FileName,PathName] = uigetfile('*.vtc', 'Please select the VTC file ');
vmr.LinkVTC([PathName FileName]);
end
% now smooth VTC with a large kernel of 10 mm:
vmr.SpatialGaussianSmoothing(10, 'mm' ); % FWHM value and unit ('mm' or 'vx')
bv.PrintToLog(['Name of spatially smoothed VTC file: ' vmr.FileNameOfCurrentVTC]);
% now we could do a linear trend removal (see code in comments)
% since high-pass temporal filter (see below) includes LTR, we skip this here
% vmr.LinearTrendRemoval(); % FWHM value and unit ('mm' or 'vx')
% bv.PrintToLog(['Name of VTC file without linear trends: ' docVMR.FileNameOfCurrentVTC]);
% now perform temporal high-pass filter
vmr.TemporalHighPassFilter(3, 'cycles'); % HP value and unit ('cycles' or 'Hz')
bv.PrintToLog(['Name of VTC file without linear trends: ' vmr.FileNameOfCurrentVTC]);
% now perform Gaussian temporal smoothing
% FWHM value and unit ('d' or 'dps' (data points) or 's' or 'secs' (seconds))
vmr.TemporalGaussianSmoothing(3, 'dps');
bv.MessageBox(['Name of temporally smoothed VTC file: ' vmr.FileNameOfCurrentVTC]);
disp('Finished preprocessing VTC file.')